## Querying old data with `query`

Deprecated in Select2 4.0. This has been replaced by another option and is only available in the full builds of Select2.

In the past, Select2 supported an option called `query` that allowed for a custom data source to be used. This option has been replaced by the `query` method on the data adapter and takes a very similar set of parameters.

Key
  `query`
Value
  A function taking `params` (including a `callback`)

Adapter
  `DataAdapter`
Decorator
  `Query`